#!/bin/sh
# Make a snapshot for dolphin-emu from its git repo
# Optional argument: commit hash or tag

BRANCH=master
STABLE=5.0

if [ ! -e dolphin.git ]; then
    echo "=== Cloning Git repository ==="
    git clone --recurse-submodules http://github.com/dolphin-emu/dolphin.git dolphin.git
fi

if [ $# == 0 ]; then
    rev="$BRANCH"
elif [ $# == 1 ]; then
    rev="$1"
fi

pushd dolphin.git
  git checkout $rev
  git pull --rebase

  # The upstream dev snapshot version seems to be the number of commits
  # since last stable tag
  snapver="$STABLE.$(git rev-list $STABLE..HEAD | wc -l)"
  echo -e "=== Exporting $rev revision, dev snapshot number $snapver ==="

  dirname="dolphin-$snapver"
  git checkout-index -a -f --prefix="../$dirname/"

  for f in $(git submodule foreach --recursive --quiet 'git ls-files --with-tree="$sha1" | sed "s#^#$path/#"'); do
     if [[ -f $f ]]; then
       install -Dp $f ../$dirname/$f
     fi
  done
popd

echo "=== Unbundling unnecessary content ==="
pushd $dirname
  rm -rf .editorconfig .git* .mailmap .tx Source/.clang-format Source/Android Installer/dxredist Installer/vcredist
  cd Externals
  rm -rf bzip2 cubeb curl enet ffmpeg fmt gettext gtest hidapi libiconv-* liblzma libpng libspng libusb lz4 LZO mbedtls miniupnpc \
       minizip OpenAL pugixml Qt SDL SFML XAudio2_7 xxhash zlib zlib-ng zstd
  # gtest // no more shared gtest, https://github.com/dolphin-emu/dolphin/commit/9ac94d01358808f9a90e472e44e8a0f6588bdec7
  # soundtouch // patched upstream
  # wxWidgets3 // needs 3.1+
popd

echo "=== Generating the tarball ==="
tar cvJf $dirname.tar.xz $dirname

rm -rf $dirname
